[llvm] 27e63d9 - Fix -Wdocumentation-html warning

David Zarzycki via llvm-commits llvm-commits at lists.llvm.org
Thu Apr 16 03:34:18 PDT 2020


Author: David Zarzycki
Date: 2020-04-16T06:33:53-04:00
New Revision: 27e63d9b0eb7db38f41084063f77768df7b95913

URL: https://github.com/llvm/llvm-project/commit/27e63d9b0eb7db38f41084063f77768df7b95913
DIFF: https://github.com/llvm/llvm-project/commit/27e63d9b0eb7db38f41084063f77768df7b95913.diff

LOG: Fix -Wdocumentation-html warning

Added: 
    

Modified: 
    llvm/include/llvm/ADT/STLExtras.h

Removed: 
    


################################################################################
diff  --git a/llvm/include/llvm/ADT/STLExtras.h b/llvm/include/llvm/ADT/STLExtras.h
index 5895cae84a71..e3b9e405f69a 100644
--- a/llvm/include/llvm/ADT/STLExtras.h
+++ b/llvm/include/llvm/ADT/STLExtras.h
@@ -112,7 +112,7 @@ using is_invocable = is_detected<detail::is_invocable, Callable, Args...>;
 
 /// This class provides various trait information about a callable object.
 ///   * To access the number of arguments: Traits::num_args
 ///   * To access the type of an argument: Traits::arg_t<i>
 ///   * To access the type of the result:  Traits::result_t
 template <typename T, bool isClass = std::is_class<T>::value>
 struct function_traits : public function_traits<decltype(&T::operator())> {};
@@ -127,8 +127,8 @@ struct function_traits<ReturnType (ClassType::*)(Args...) const, false> {
   using result_t = ReturnType;
 
   /// The type of an argument to this function.
-  template <size_t i>
-  using arg_t = typename std::tuple_element<i, std::tuple<Args...>>::type;
+  template <size_t Index>
+  using arg_t = typename std::tuple_element<Index, std::tuple<Args...>>::type;
 };
 /// Overload for class function types.
 template <typename ClassType, typename ReturnType, typename... Args>
@@ -112,7 +112,7 @@ using is_invocable = is_detected<detail::is_invocable, Callable, Args...>;
 /// This class provides various trait information about a callable object.
 ///   * To access the number of arguments: Traits::num_args
-///   * To access the type of an argument: Traits::arg_t<i>
+///   * To access the type of an argument: Traits::arg_t<Index>
 ///   * To access the type of the result:  Traits::result_t
 template <typename T, bool isClass = std::is_class<T>::value>


        


More information about the llvm-commits mailing list